@@ -6,10 +6,10 @@ from mdplus import multiscale
 from mdplus.utils import rmsd
 
 rootdir = os.path.dirname(os.path.abspath('__file__'))
-ncfile = os.path.join(rootdir, 'test/examples/test.nc')
-pdbfile = os.path.join(rootdir, 'test/examples/test.pdb')
-pczfile = os.path.join(rootdir, 'test/examples/test.pcz')
-pczfile_dm = os.path.join(rootdir, 'test/examples/test_dm.pcz')
+ncfile = os.path.join(rootdir, 'examples/test.nc')
+pdbfile = os.path.join(rootdir, 'examples/test.pdb')
+pczfile = os.path.join(rootdir, 'examples/test.pcz')
+pczfile_dm = os.path.join(rootdir, 'examples/test_dm.pcz')
 
 @pytest.fixture(scope="module")
 def cg_traj():
